.. code-block:: python

  print('x is currently:', x)
  raise Exception('the start!')

XXXX 4 check

YYY 2 check

XXX 4 check

YYY 3 check

.. code-block:: python

  x += 1
  if x > 0:
      raise Exception('boom!')

